==> connectagram_1.2.4.orig.tar.gz: connectagram-1.2.4/translations/connectagram_es_PE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_PE">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Cadena</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definiciones</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Descargando definición...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Palabra sin resolver</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definición de Wiktionary, el diccionario libre</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>No se ha encontrado definición</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>No es posible conectar con Wiktionary</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elegir idioma</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma de sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicia la aplicación para que los cambios en el idioma se efectuen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuevo Juego</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Muy alto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Largo de palabra:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantidad de palabras:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Anillos</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Puntajes</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntaje</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Palabras</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Largo</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Escalera</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Revuelto</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definiciones</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Pista</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elige</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalles</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Pista</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efiniciones</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Puntajes</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Ac%erca de...</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Juego</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Juego número:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>No se puede iniciar el juego solicitado</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Un juego de palabras desordenadas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copu; 2009-%1 por Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Licenciado bajo &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Las definiciones son de &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Figura:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Volver</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_es_PE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_PE">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Cadena</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Elegir idioma</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma de sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicia la aplicación para que los cambios en el idioma se efectuen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuevo Juego</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Muy alto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Largo de palabra:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantidad de palabras:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Anillos</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntaje</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Palabras</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Largo</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Escalera</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Revuelto</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definiciones</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Pista</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elige</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalles</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Pista</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efiniciones</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Ac%erca de...</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Juego</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Juego número:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>No se puede iniciar el juego solicitado</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Un juego de palabras desordenadas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copu; 2009-%1 por Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Licenciado bajo &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Las definiciones son de &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Figura:</translation>
    </message>
</context>
</TS>
